Installer class abstract

Implementers

Constructors

Installer.init({required UpgradeStateChangeNotifier state})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → UpgradeStateChangeNotifier
no setter
status → UpgradeStatus
no setter

Methods

download({String? url, File? file, void onReceiveProgress(int received, int total, bool failed)?, void onDone()?}) → void
hasDownload() → bool
install() → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

from<T extends Installer>(UpgradeStateChangeNotifier state, Map<String, dynamic> json, T factory(UpgradeStateChangeNotifier state, Map<String, dynamic> data)) → T