UpgradeManager class

Properties

current → AppcastItem?
no setter
hashCode → int
The hash code for this object.
no setterinherited
installer → Installer?
no setter
latest → AppcastItem?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → UpgradeStateChangeNotifier
no setter
status → UpgradeStatus
no setter

Methods

addListener(void listener()) → void
checkForUpdates() → void
dismiss() → void
download({String? url, File? file, void onReceiveProgress(int received, int total, bool failed)?, void onDone()?}) → void
init({required String url, required String currentVersionPath, List<InstallInitializer> customInstallInitializers = const [], bool crashIfNoLegalConfigFile = false}) → void
initInstallers() → void
install() → Future<bool>
nextInstaller() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeListener(void listener()) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → UpgradeManager
no setter