AndroidApkInstaller class

Inheritance

Constructors

AndroidApkInstaller({required UpgradeStateChangeNotifier state, required String fileURL, bool closeOnInstalling = false})

Properties

closeOnInstalling ↔ bool
getter/setter pairinherited
filePath ↔ String?
getter/setter pairinherited
fileURL ↔ String
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → UpgradeStateChangeNotifier
no setterinherited
status → UpgradeStatus
no setterinherited

Methods

download({String? url, File? file, void onReceiveProgress(int received, int total, bool failed)?, void onDone()?}) → void
inherited
hasDownload() → bool
inherited
install() → Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited