FileInstaller class

Inheritance
Implementers

Constructors

FileInstaller({required UpgradeStateChangeNotifier state, required String fileURL, required bool closeOnInstalling})

Properties

closeOnInstalling ↔ bool
getter/setter pair
filePath ↔ String?
getter/setter pair
fileURL ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → UpgradeStateChangeNotifier
no setterinherited
status → UpgradeStatus
no setterinherited

Methods

download({String? url, File? file, void onReceiveProgress(int received, int total, bool failed)?, void onDone()?}) → void
override
hasDownload() → bool
override
install() → Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited